.. django-mailrobot documentation master file, created by
   sphinx-quickstart on Fri Nov 22 14:13:46 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-mailrobot's documentation!
============================================

Stores and sends canned email responses.

Ever had to change the signature or add a recipient to N hardcoded emails
spread all throughout your code? Hardcode no more! Use mailrobot instead.

Contents:

.. toctree::
   :maxdepth: 2

   installation.rst
   usage.rst
   testing.rst
   models.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

